==> haskell-network-protocol-xmpp-0.4.8-126-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-LsPHo93BzRA5Emo068POiL
key: network-protocol-xmpp-0.4.8-LsPHo93BzRA5Emo068POiL
license: GPL-3.0-only
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
abi: 10a454c32ce1addc62e97e80bab67f10
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-protocol-xmpp-0.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-LsPHo93BzRA5Emo068POiL
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    gnuidn-0.2.2-FqiB65R6H5DeTvY2GYuBa
    gnutls-0.2-5gUB3jzvl1o3ZmuCptzwPf gsasl-0.3.6-7O7quw7QB4uyUuDYdrPte
    libxml-sax-0.7.5-4zvThBcDksZKjZMmnQUocC
    monads-tf-0.1.0.3-KfvB5lplvTy3onJzEY5Ljt
    network-2.8.0.0-1M86biZqFSo3ZnJTr6WevT text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.8-127-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-E6iunakWga16dnzyTbbLZe
key: network-protocol-xmpp-0.4.8-E6iunakWga16dnzyTbbLZe
license: GPL-3.0-only
maintainer: John Millikin <jmillikin@gmail.com>
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
abi: 5339e5f395b1483c327697a84638f5c8
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
import-dirs: /usr/lib/ghc-8.6.5/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/network-protocol-xmpp-0.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-E6iunakWga16dnzyTbbLZe
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    gnuidn-0.2.2-FqiB65R6H5DeTvY2GYuBa
    gnutls-0.2-5gUB3jzvl1o3ZmuCptzwPf gsasl-0.3.6-7O7quw7QB4uyUuDYdrPte
    libxml-sax-0.7.5-4zvThBcDksZKjZMmnQUocC
    monads-tf-0.1.0.3-KfvB5lplvTy3onJzEY5Ljt
    network-2.8.0.0-3PgnnHopFNTASnxFyU0kPh text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
